package com.jiuqi.util;

import com.jiuqi.util.chinese.ChineseDouble;
import com.jiuqi.util.chinese.ChineseInt;
import com.jiuqi.util.chinese.NoValidCharException;
import com.jiuqi.util.chinese.NotValidChineseNumberException;
import java.text.FieldPosition;
import java.text.NumberFormat;
import java.text.ParsePosition;

public class ChineseNumberFormat extends NumberFormat {
   private boolean useCapital;
   private int decimal;
   private static String[] chDigitUnits = new String[]{"", "十", "百", "千", "万", "十万", "百万", "千万", "亿", "十亿", "百亿", "千亿", "万亿", "兆"};

   public ChineseNumberFormat() {
      this.useCapital = false;
      this.decimal = 2;
   }

   public ChineseNumberFormat(boolean useCapital) {
      this.useCapital = useCapital;
      this.decimal = 2;
   }

   public ChineseNumberFormat(boolean useCapital, int decimal) {
      this.useCapital = useCapital;
      this.decimal = decimal;
   }

   public boolean getUseCapital() {
      return this.useCapital;
   }

   public void setUseCapital(boolean value) {
      this.useCapital = value;
   }

   public int getDecimal() {
      return this.decimal;
   }

   public void setDecimal(int value) {
      this.decimal = value;
   }

   public Number parse(String source, ParsePosition parsePosition) {
      if (source == null) {
         return null;
      } else {
         NoValidCharException e;
         NotValidChineseNumberException e;
         if (source.indexOf("点") == -1 && source.indexOf("分之") == -1) {
            try {
               return new Long(ChineseInt.valueOf(source));
            } catch (NotValidChineseNumberException var4) {
               e = var4;
               e.printStackTrace();
               return null;
            } catch (NoValidCharException var5) {
               e = var5;
               e.printStackTrace();
               return null;
            }
         } else {
            try {
               return new Double(ChineseDouble.valueOf(source));
            } catch (NotValidChineseNumberException var6) {
               e = var6;
               e.printStackTrace();
               return null;
            } catch (NoValidCharException var7) {
               e = var7;
               e.printStackTrace();
               return null;
            }
         }
      }
   }

   public StringBuffer format(double number, StringBuffer toAppendTo, FieldPosition pos) {
      String value = ChineseDouble.parseToChinese(String.valueOf(number), this.decimal, false, this.useCapital);
      toAppendTo.append(value);
      return toAppendTo;
   }

   public StringBuffer format(long number, StringBuffer toAppendTo, FieldPosition pos) {
      String value = ChineseInt.parseToChinese(String.valueOf(number), false, this.useCapital);
      toAppendTo.append(value);
      return toAppendTo;
   }

   public static String toChineseDigitUnit(double unitValue) {
      return toChineseDigitUnit((long)Math.rint(unitValue));
   }

   public static String toChineseDigitUnit(long unitValue) {
      int factor;
      for(factor = 0; unitValue >= 10L; ++factor) {
         unitValue /= 10L;
      }

      return factor >= chDigitUnits.length ? null : chDigitUnits[factor];
   }
}
